/* $Id: lambert1.cpp 103 2008-08-07 14:08:33Z dirk $ */

/* GCL - Geodetic Computation Library
 * Copyright (C) 2005 Dirk Stallmann
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
#include "lambert1.h"

namespace GCL
{

// get map projection name

const char* Lambert1::map_name() const
{
	return "Lambert conformal conic (1SP)";
}


// To convert geodetic coordinates into Lambert Conformal Conic coords.

void Lambert1::geo_to_map(double b, double l, double& x, double& y) const
{
	double n = sin(_b0);
	double dl = n * (l - _l0);
	double R0 = _m0 * nradius(_b0) / tan(_b0);
	//double c = R0 * exp(n * q(_b0));
	//double R = c / exp(n * q(b));
	double R = R0 * exp(n * (q(_b0) - q(b)));
	//cout << q(b) << endl;

	x = _x0 + R * sin(dl);
	y = _y0 + R0 - R * cos(dl);
}


// To convert Lambert Conformal Conic coords. into  geodetic coordinates 

void Lambert1::map_to_geo(double x, double y, double& b, double& l) const
{
	double n = sin(_b0);
	double R0 = _m0 * nradius(_b0) / tan(_b0);
	double dl = atan((x - _x0) / (_y0 + R0 - y));
	double dx = x - _x0;
	double dy = y - _y0 - R0;
	double R = sqrt(dx * dx + dy * dy);
	//double c = R0 * exp(n * q(_b0));
	//double q = -log(R / c) / n;
	double q = Ellipsoid::q(_b0) - log(R / R0) / n;

	b = inv_q(q);
	l = _l0 + dl / n;
}

} // namespace GCL
