/* $Id: lambert2.h 103 2008-08-07 14:08:33Z dirk $ */

/* GCL - Geodetic Computation Library
 * Copyright (C) 2005 Dirk Stallmann
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
#ifndef GCL_LAMBERT2_INCLUDED
#define GCL_LAMBERT2_INCLUDED

#include "projection.h"

namespace GCL
{

/**@brief Lambert Conformal Conic Projection with two standard parallels
 *
 *  Conversion routines for Lambert Conformal Conic coordinates.
 *  @author Dirk Stallmann
 */
class Lambert2 : public Projection
{
public:
	/**@brief constructor with ellipsoid name
	 * @param ell_name  name of the reference ellipsoid
	 */
	Lambert2(const string& ell_name) : Projection(ell_name) {}

	/// get map projection name
	const char* map_name() const;

	/// set standard parallel 1 and 2
	void std_parallel(double b1, double b2) { _b1 = b1; _b2 = b2; }

	/// print parameters
	void print(ostream& os) const;

	/**@name conversion routines
	 * conversion between geodetic and map coordinates
	 */
	//@{
		/**@brief convert geodetic into map coordinates
		 * @param[in]  b,l  geodetic coordinates, latitude and longitude in radian
		 * @param[out] x,y  map coordinates in meter
		 */
		void geo_to_map(double b, double l, double& x, double& y) const;

		/**@brief convert map into geodetic coordinates
		 * @param[in]  x,y  map coordinates in meter
		 * @param[out] b,l  geodetic coordinates, latitude and longitude in radian
		 */
		void map_to_geo(double x, double y, double& b, double& l) const;
	//@}

private:
	/// standard parallel 1
	double _b1;

	/// standard parallel 2
	double _b2;
};

} // namespace GCL

#endif
