/* $Id: polrec.h 103 2008-08-07 14:08:33Z dirk $ */

/* GCL - Geodetic Computation Library
 * Copyright (C) 2005 Dirk Stallmann
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
#ifndef GCL_POLREC_INCLUDED
#define GCL_POLREC_INCLUDED

namespace GCL
{

/**@defgroup conversion Coordinate conversion
 * @brief polar-rectangular coordinates conversion
 *
 *  To convert between polar coordinates
 *  - geocentric latitude (\e psi)
 *  - geographic longitude (\e l) positive due east
 *  - geocentric distance (\e r)
 *
 *  and righthanded rectangular coordinates
 *  - x-coordinate in Greenwich meridian (\e x)
 *  - y-coordinate due east (\e x)
 *  - z-coordinate due north (\e x)
 *
 *  References:
 *  - Heck: Rechenverfahren und Auswertemodelle der Landesvermessung,
 *          Wichmann Verlag, Karlsruhe, 1987.
 *
 *  @author Dirk Stallmann
 */
//@{
	/** convert polar into rectangular coordinates
	 *  @param[in] psi      geocentric latitude
	 *  @param[in] l       geographic longitude
	 *  @param[in] r        geocentric distance
	 *  @param[out] x,y,z   rectangular coordinates
	 */
	void pol_to_rec(double psi, double l, double r,
		double& x, double& y, double& z);

	/** convert rectangular into polar coordinates
	 *  @param[in] x,y,z    rectangular coordinate
	 *  @param[out] psi     geocentric latitude
	 *  @param[out] l       geographic longitude
	 *  @param[out] r       geocentric distance
	 */
	void rec_to_pol(double x, double y, double z,
		double& psi, double& l, double& r);
//@}

} // namespace GCL

#endif
