/* $Id: projection.cpp 103 2008-08-07 14:08:33Z dirk $ */

/* GCL - Geodetic Computation Library
 * Copyright (C) 2005 Dirk Stallmann
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

#include <cstring>
#include <cassert>
#include <string>
#include "form.h"
#include "projection.h"

using namespace GenLib2;


namespace GCL
{

// projection name map

Projection::map_t Projection::_map[] =
{
	{ UNKNOWN,			"unknown" },
	{ GKK,				"GKK" },
	{ UTM,				"UTM" },
	{ LAMBERT1,			"Lambert1" },
	{ LAMBERT2,			"Lambert2" },
	{ SLK,				"SLK" }, // synomym for backward compability
	{ SPK,				"SPK" },
	{ SPKLV03,			"SPK_LV03" },
	{ SPKLV95,			"SPK_LV95" },
	{ END_OF_MAP,		0 }
};


// get map projection name

const char* Projection::map_name() const
{
	return "undefined";
}


// print general projection parameters

void Projection::print(ostream& os) const
{
	Form fix3(3); fix3.fixed().width(14);
	Form fix6(6); fix6.fixed().width(14);
	Form fix8(8); fix8.fixed().width(14);

	os << "Map projection name       :  "
		<< map_name() << "\n";
	os << "Latitude of origin        :  b0   = " << fix8(_b0*rho_deg)
		<< " deg\n";
	os << "Longitude of origin       :  l0   = " << fix8(_l0*rho_deg)
		<< " deg\n";
	os << "Scale factor              :  m0   = " << fix6(_m0)
		<< "\n";
	os << "Offset in x               :  x0   = " << fix3(_x0)
		<< " m\n";
	os << "Offset in y               :  y0   = " << fix3(_y0)
		<< " m\n";
}


// get code

Projection::ecode Projection::code(const char* map_name)
{
	for (int i = 0; _map[i].name != 0; i++)
		{
		if (strcmp(map_name, _map[i].name) == 0)
			return (ecode)_map[i].code;
		}

	return (ecode)_map[0].code;
}


} // namespace GCL
