/* $Id: utm.cpp 103 2008-08-07 14:08:33Z dirk $ */

/* GCL - Geodetic Computation Library
 * Copyright (C) 2005 Dirk Stallmann
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

#include "utm.h"
using namespace GenLib2;

namespace GCL
{

// get map projection name

const char* UTM::map_name() const
{
	return "UTM";
}


// zone number

int UTM::zone(double l0) const
{
	return (int((l0 * rho_deg + 3.) / 6.) + 30);
}


// meridian

double UTM::lambda0(int nz) const
{
	return ((6. * abs((double)nz) - 183.) / rho_deg);
}


// convert geodetic into UTM coordinates

void UTM::geo_to_map(double b, double l, double& e, double& n) const
{
	double x, y;

	geo_to_iso(b, l, x, y);

	//e = y + 500000.;
	e = y;
	n = (b > 0.) ? (x) : (x + 10000000.);
}


// convert UTM into geodetic coordinates

void UTM::map_to_geo(double e, double n, double& b, double& l) const
{
	//double x = (nz > 0) ? (n) : (n - 10000000.);
	double x = n;
	//double y = e - 500000.;
	double y = e;
	//double l0 = lambda0(nz);

	iso_to_geo(x, y, b, l);
}

} // namespace GCL
